@@ -94,5 +94,55 @@ def reset(task_name):
     # seeking to 0
     # starting
 
+@main.command()
+@pass_repo
+def topics(repo):
+    topics = set()
+
+    for task in [repo.load_task(x) for x in repo.tasks()]:
+        topics.update(task.source_topics)
+        topics.update(task.result_topics)
+
+    for t in sorted(topics):
+        print t
+
+@main.command()
+@pass_repo
+@click.argument('task')
+def offsets(repo, task):
+
+    task = repo.load_task(task)
+    from .state import StateManager
+    state_manager = StateManager(repo.state_dir())
+    ostore = state_manager.get_offset_store(task)
+
+    from pymza.offset import SimpleOffsetTracker
+
+    offset = SimpleOffsetTracker()
+    ostore.load(offset)
+
+    print offset._offsets
+
+
+@main.command()
+@click.argument('topic')
+def topic_tail(topic):
+    from kafka import KafkaClient, SimpleConsumer
+
+    # To send messages synchronously
+    kafka = KafkaClient("localhost:9092")
+
+    # To consume messages
+    consumer = SimpleConsumer(kafka, "my-group", str(topic), auto_commit=False, max_buffer_size=10*1024*1024)
+    consumer.provide_partition_info()
+    consumer.seek(0, 0)
+    click.echo("Tailing {0}, {1} messages pending".format(topic, consumer.pending()))
+    for partition, message in consumer:
+        print 'k:', message.message.key
+        print 'v:', message.message.value
+        print
+
+    kafka.close()    
+
 if __name__ == '__main__':
     main()
\ No newline at end of file
