@@ -16,8 +16,8 @@ class Repo(object):
         return TaskCode(__import__(name, globals(), {}, [], -1))
 
     def tasks(self):
-        return [x.strip() for x in self.config.get('main', 'tasks').split(',')]
+        return [self.config.get(x, 'task').strip() for x in self.config.sections()]
 
     def state_dir(self):
-        path = self.config.get('main', 'state_dir') or './state'
+        path = self.config.get('DEFAULT', 'state_dir') or './state'
         return os.path.join(self.home, path)
