@@ -94,6 +94,29 @@ class Task(object):
 
             partition_ids = self.kafka.get_partition_ids_for_topic(topic)
 
+            # fetch offset range for each partition
+            reqs = [kafka.common.OffsetRequest(topic, partition_id, -1, 10000) for partition_id in partition_ids]
+            resps = self.kafka.send_offset_request(reqs) 
+            for resp in resps:
+                kafka.common.check_error(resp)
+                partition_id = resp.partition
+                our_offset = self.offsets.get(topic, partition_id)
+                print resp.offsets
+                server_max = resp.offsets[0]
+                if len(resp.offsets) > 1:
+                    server_min = resp.offsets[1]
+                else:
+                    server_min = server_max
+                if our_offset > server_max:
+                    raise RuntimeError('Stored offset for topic {0} and partition {1} ({2}) is larger '
+                        'than maximal offset on server ({3}). This could be caused by state not synchronized '
+                        'with data in Kafka. You are adviced to wipe state and reprocess all data in Kafka.'.format(topic, partition_id, our_offset, server_max))
+                elif our_offset < server_min:
+                    self.logger.warn('Our offset for topic {0} and partition {1} ({2}) is smaller than'
+                    ' minimal offset on server ({3}). This could be caused by log compaction. Updating '
+                    'our offset to server minimal offset.'.format(topic, partition_id, our_offset, server_min))
+                    raise ReferenceError('temporary check')
+
             # set consumer offsets to stored ones
             for partition in partition_ids:
                 consumer.offsets[partition] = self.offsets.get(topic, partition)
@@ -163,20 +186,24 @@ class Task(object):
 
             # self.offsets.commit()
 
-    def handle_task_result(self, result):
-        if isinstance(result, types.GeneratorType):
-            result = list(result)
-        elif result is None:
-            result = []
-        else:
-            result = [result]
-
-        for topic, key, value in result:
-            if topic not in self.result_topics:
-                self.logger.error('Task yielded data into {0} but task result topics defined as {1}. Message not sent.'.format(topic, list(self.result_topics)))
-                continue
-            self.producer.send(topic.encode('utf-8'), key.encode('utf-8'), json.dumps(value))
+    def handle_task_result(self, results):
+        if results is None:
+            results = []
 
+        try:
+            for result in results:
+                if result is None:
+                    continue
+                topic, key, value = result
+                if topic not in self.result_topics:
+                    self.logger.error('Task yielded data into {0} but task result topics defined as {1}. Message not sent.'.format(topic, list(self.result_topics)))
+                    raise
+                if key is None:
+                    self.logger.error('Task yielded data with no key. Message not sent.')
+                self.producer.send(topic.encode('utf-8'), key.encode('utf-8'), json.dumps(value))
+        except Exception:
+            self.logger.exception('Failed to process result of {0}'.format(self.name))
+            raise
 
 def _reader_thread(task, consumer, queue):
     sleep = ExponentialSleep(0.1, 10, 2.0)
